@@ -4,6 +4,7 @@ __all__: Sequence[str] = (
     "CrescentException",
     "AlreadyRegisteredError",
     "PluginAlreadyLoadedError",
+    "PermissionsError",
 )
 
 
@@ -17,3 +18,7 @@ class AlreadyRegisteredError(CrescentException):
 
 class PluginAlreadyLoadedError(CrescentException):
     """A plugin is attempted to be loaded but the plugin manager already loaded the plugin."""
+
+
+class PermissionsError(CrescentException):
+    """Raise when a permission is declared in a subcommand"""
